package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcYqxxltj;
import com.ruoyi.tcZz.domain.TcYqyj;
import com.ruoyi.tcZz.service.ITcYqyjService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 舆情预警Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "舆情预警")
@RequestMapping("/tcZz/netWorkYq/yqyj")
public class TcYqyjController extends BaseController {
    @Autowired
    private ITcYqyjService tcYqyjService;

    /**
     * 查询舆情预警列表
     */
    @ApiOperation(value = "查询舆情预警列表", response = TcYqyj.class)
    @GetMapping("/list")
    public TableDataInfo list(TcYqyj tcYqyj) {
        startPage();
        List<TcYqyj> list = tcYqyjService.selectTcYqyjList(tcYqyj);
        return getDataTable(list);
    }

    /**
     * 导出舆情预警列表
     */
    @ApiOperation(value = "导出舆情预警列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYqyj tcYqyj) {
        List<TcYqyj> list = tcYqyjService.selectTcYqyjList(tcYqyj);
        ExcelUtil<TcYqyj> util = new ExcelUtil<TcYqyj>(TcYqyj.class);
        util.exportExcel(response, list, "舆情预警数据");
    }

    /**
     * 获取舆情预警详细信息
     */
    @ApiOperation(value = "获取舆情预警详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcYqyjService.selectTcYqyjById(id));
    }

    /**
     * 新增舆情预警
     */
    @ApiOperation(value = "新增舆情预警")
    @PostMapping
    public AjaxResult add(@RequestBody TcYqyj tcYqyj) {
        return toAjax(tcYqyjService.insertTcYqyj(tcYqyj));
    }

    /**
     * 修改舆情预警
     */
    @ApiOperation(value = "修改舆情预警")
    @PutMapping
    public AjaxResult edit(@RequestBody TcYqyj tcYqyj) {
        return toAjax(tcYqyjService.updateTcYqyj(tcYqyj));
    }

    /**
     * 删除舆情预警
     */
    @ApiOperation(value = "删除舆情预警")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcYqyjService.deleteTcYqyjByIds(ids));
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcYqyj> util = new ExcelUtil<TcYqyj>(TcYqyj.class);
        List<TcYqyj> tcYqyjList = util.importExcel(file.getInputStream());
        tcYqyjService.importUser(tcYqyjList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus,@RequestParam("ids") List<String> ids) {
        tcYqyjService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcYqyj> util = new ExcelUtil<TcYqyj>(TcYqyj.class);
        util.importTemplateExcel(response, " 舆情预警");
    }
}
